@@ -19,6 +19,7 @@ import os
 import re
 import sys
 import string
+import codecs
 import platform
 
 py3 = platform.python_version()[0] == '3'
@@ -37,17 +38,14 @@ class LogReader(object):
     """Opens a Log file, reading backwards and watching for changes"""
     def __init__(self, filename, mass=4096):
         self.filename = filename
-        if py3:
-            self.pipe = open(filename, 'r', encoding='utf-8')
-        else:
-            self.pipe = open(filename, 'r')
+        self.pipe     = codecs.open(filename, 'r', encoding='utf-8')
         self.mass     = mass
         self.size     = -1
         self.read     = -1
 
     def readlines(self, until=0):
         """Iterator for reading lines from a file backwards"""
-        if not self.pipe:
+        if not self.pipe or self.pipe.closed:
             raise IOError("Can't readline, no opened file.")
         # Always seek to the end of the file, this accounts for file updates
         # that happen during our running process.
@@ -58,14 +56,16 @@ class LogReader(object):
 
         while location > until:
             location -= self.mass
+            mass = self.mass
             if location < 0:
+                mass = self.mass + location
                 location = 0
             self.pipe.seek(location)
-            data = self.pipe.read(self.mass) + halfline
-            data = data.strip().split('\n')
+            line = self.pipe.read(mass) + halfline
+            data = line.split('\n')
             if location != 0:
                 halfline = data.pop(0)
-            loc = location + self.mass
+            loc = location + mass
             data.reverse()
             for line in data:
                 if line.strip() == '':
@@ -79,9 +79,7 @@ class LogReader(object):
 
 
 class CronLog(LogReader):
-    def __init__(self, filename=None, user=None):
-        if not filename:
-            filename = '/var/log/syslog'
+    def __init__(self, filename='/var/log/syslog', user=None):
         LogReader.__init__(self, filename)
         self.user = user
 
@@ -107,7 +105,4 @@ class ProgramLog(object):
         for entry in self.log:
             if entry['cmd'] == unicode(self.command):
                 yield entry
-            #else:
-            #    print "'%s' != '%s'" % (entry['cmd'], self.command)
-
 
